<?php

use EventPortal\Http\Controllers\Admin\Delegate\DelegateController;
use EventPortal\Http\Controllers\Admin\Event\ArchivedEventController;
use EventPortal\Http\Controllers\Admin\Event\EventController;
use EventPortal\Http\Controllers\Admin\EventDelegate\DelegatesNotOnEventController;
use EventPortal\Http\Controllers\Admin\EventDelegate\EventDelegateController;

Route::get('/', 'DashboardController')->name('admin.dashboard.index');

Route::group(['prefix' => 'events'], function (): void {
    Route::group(['prefix' => '{event}/delegates'], static function (): void {
        Route::get('/add', [DelegatesNotOnEventController::class, 'index'])->name('admin.event.delegate.create');
        Route::post('/add', 'EventDelegate\AssociateToEventController')->name('admin.event.delegate.store');
        Route::post('/remote', 'EventDelegate\DisassociateFromEventController')->name('admin.event.delegate.destroy');

        Route::get('/', [EventDelegateController::class, 'index'])->name('admin.event.delegate.index');
        Route::get('{delegate}', [EventDelegateController::class, 'show'])->name('admin.event.delegate.show');
        Route::post(
            '{delegate}/transition/{type}',
            'EventDelegate\EventDelegateTransitionController'
        )->name('admin.event.delegate.transition');
    });

    Route::get('/archived', [ArchivedEventController::class, 'index'])->name('admin.archived-event.index');

    Route::get('/', [EventController::class, 'index'])->name('admin.event.index');
    Route::post('/', [EventController::class, 'store'])->name('admin.event.store');
    Route::get('create', [EventController::class, 'create'])->name('admin.event.create');
    Route::get('{event}', [EventController::class, 'show'])->name('admin.event.show');
    Route::get('{event}/edit', [EventController::class, 'edit'])->name('admin.event.edit');
    Route::post('{event}/update', [EventController::class, 'update'])->name('admin.event.update');
    Route::post('{event}/delete', [EventController::class, 'delete'])->name('admin.event.delete');

    Route::post('{event}/transition/{type}', 'Event\EventTransitionController')->name('admin.event.transition');
});

Route::group(['prefix' => 'permissions'], function (): void {
    Route::get('/', 'PermissionController@index')->name('admin.permission.index');
    Route::post('/', 'PermissionController@update')->name('admin.permission.update');
});

Route::post('user-type/', 'RoleController@store')->name('admin.role.store');

Route::group(['prefix' => 'delegates'], function (): void {
    Route::get('/', [DelegateController::class, 'index'])->name('admin.delegate.index');
    Route::get('create', [DelegateController::class, 'create'])->name('admin.delegate.create');
    Route::post('/', [DelegateController::class, 'store'])->name('admin.delegate.store');
    Route::get('{delegate}/edit', [DelegateController::class, 'edit'])->name('admin.delegate.edit');
    Route::post('{delegate}/update', [DelegateController::class, 'update'])->name('admin.delegate.update');
    Route::get('{delegate}', [DelegateController::class, 'show'])->name('admin.delegate.show');
});
