<?php

namespace EventPortal\Domain\Component;

use EventPortal\Concerns\HasWhen;
use Illuminate\Support\Arr;
use Illuminate\Support\Str;

abstract class Component
{
    use HasWhen;

    const TYPE = 'Component';

    /** @var string */
    public $component;

    /** @var null|string */
    public $name;

    /** @var string */
    public $label;

    /** @var null|string */
    public $classes;

    /** @var string */
    public $scope;

    public function __construct(?string $label = null)
    {
        $this->label = $label;
        $this->name = $label !== null ? Str::slug($label, '_') : null;
        $this->component = $this::TYPE;
    }

    public static function make(?string $label = null): self
    {
        return new static($label);
    }

    public function name(?string $name): self
    {
        $this->name = $name;

        return $this;
    }

    public function label(string $label): self
    {
        $this->label = $label;

        return $this;
    }

    /**
     * @param string|array|null $classes
     */
    public function classes($classes): self
    {
        $this->classes = Arr::wrap($classes);

        return $this;
    }

    public function scopeTo(string $scope): self
    {
        $this->scope = $scope;

        return $this;
    }

    public function isScoped(): bool
    {
        return $this->scope !== null;
    }

    public function isNotScoped(): bool
    {
        return $this->isScoped() === false;
    }

    public function scopeKey(): string
    {
        return "{$this->scope}.{$this->name}";
    }
}
