<?php

namespace EventPortal\Domain\Event\Models;

use EventPortal\Concerns\HasStatus;
use EventPortal\Contracts\Statusable;
use EventPortal\Domain\Delegate\Models\Delegate;
use Iben\Statable\Statable;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\Pivot;

class EventDelegate extends Pivot implements Statusable
{
    use Statable, HasStatus;

    const KEY = 'eventDelegate';

    /** @var string */
    protected $table = 'delegate_event';

    /** @var array<string> */
    protected $fillable = [
        'status',
    ];

    public function event(): BelongsTo
    {
        return $this->belongsTo(Event::class);
    }

    public function delegate(): BelongsTo
    {
        return $this->belongsTo(Delegate::class);
    }

    public function scopeForEventAndDelegate(Builder $query, Event $event, Delegate $delegate): Builder
    {
        return $query
            ->where('event_id', $event->id)
            ->where('delegate_id', $delegate->id);
    }

    protected function getGraph(): string
    {
        return 'eventDelegate';
    }

    public function transitionRouteName(): string
    {
        return 'admin.event.delegate.transition';
    }

    public function transitionRouteParameters(): array
    {
        return [
            'event' => $this->event->id,
            'delegate' => $this->delegate->id,
        ];
    }
}
