<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\ButtonDropdown;
use EventPortal\Domain\Component\Dropdown\Select;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Util\Status;
use EventPortal\Enums\InertiaMethod;
use Illuminate\Database\Eloquent\Builder;

Table::make('event-delegate.index')
    ->tapQuery(function (Builder $query) {
        return $query->joinRelationship('user');
    })
    ->addAvailableColumns(function () {
        return [
            Text::make('First name'),
            Text::make('Last name'),
            Text::make('Email'),
            Select::make('Status')->options(Status::make('event_delegate')->forFilters()),
        ];
    })
    ->addGlobalAction(function (Event $event) {
        return Button::make('Remove from event')
            ->method(InertiaMethod::POST())
            ->route('admin.event.delegate.destroy', ['event' => $event]);
    })
    ->addGlobalAction(function () {
        return ButtonDropdown::make('Manage delegate')
            ->actions([
                Button::make('Do something cool')->method(InertiaMethod::VISIT()),
                Button::make('Do something else cool')->method(InertiaMethod::VISIT()),
            ]);
    })
    ->addRowAction(function (Event $event, Delegate $delegate) {
        return ButtonDropdown::make('Manage delegate')
            ->actions([
                Button::make('View')
                    ->method(InertiaMethod::VISIT())
                    ->route('admin.event.delegate.show', [
                        'event' => $event->id,
                        'delegate' => $delegate->id,
                    ]),
            ]);
    });

Table::make('event-delegate.add')
    ->joinRelation('user')
    ->addGlobalAction(function (Event $event) {
        return ButtonDropdown::make('Manage delegates')
            ->actions([
                Button::make('Add')
                    ->method(InertiaMethod::POST())
                    ->route('admin.event.delegate.add', [
                        'event' => $event->id,
                    ]),
            ]);
    })
    ->addGlobalAction(function (Event $event) {
        return Button::make('Add to event')
            ->method(InertiaMethod::POST())
            ->route('admin.event.delegate.store', ['event' => $event]);
    });

