<?php

namespace EventPortal\Tests\Feature\Admin\Event;

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Permission\Models\Permission;
use EventPortal\Domain\User\Models\User;
use EventPortal\Enums\InertiaMethod;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Spatie\Snapshots\MatchesSnapshots;

class EventEditTest extends TestCase
{
    use RefreshDatabase, MatchesSnapshots;

    public function setUp(): void
    {
        parent::setUp();
        $user = factory(User::class)->create();
        $permission = factory(Permission::class)->create([
            'name' => 'event.update'
        ]);
        $user->givePermissionTo($permission->id);
        $this->actingAs($user);
    }

    /** @test **/
    public function can_edit_event()
    {
        $event = factory(Event::class)->create(['name' => 'Hello World!']);

        Form::make('event.edit')
            ->addFields(function () {
                return [
                    Section::make('Key details')->fields([
                        Text::make('name'),
                    ]),
                ];
            })
            ->addActions(function (Event $event) {
                return [
                    Button::make('Cancel')
                        ->variant('secondary')
                        ->method(InertiaMethod::VISIT())
                        ->route('admin.event.index'),
                    Button::make('Update event')
                        ->method(InertiaMethod::POST())
                        ->route('admin.event.update', ['event' => $event]),
                ];
            });

        $this->assertMatchesJsonSnapshot(
            $this->get(route('admin.event.edit', $event->id))->props()
        );
    }
}
