<?php

namespace EventPortal\Tests\Feature\Admin\Event;

use EventPortal\Domain\Component\Display;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Permission\Models\Permission;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Spatie\Snapshots\MatchesSnapshots;

class EventShowTest extends TestCase
{
    use DatabaseMigrations, MatchesSnapshots;

    /** @test */
    public function can_view_event()
    {
        $user = factory(User::class)->create();
        $permission = factory(Permission::class)->create([
            'name' => 'event.show'
        ]);
        $user->givePermissionTo($permission->id);

        $event = factory(Event::class)->create(['name' => 'Hello World!']);

        Form::make('event.edit')
            ->addFields(function () {
                return [
                    Section::make('Key details')->fields([
                        Display::make('name'),
                    ]),
                ];
            });

        $this->assertMatchesJsonSnapshot(
            $this->actingAs($user)
                ->get(route('admin.event.show', $event))->props()
        );
    }
}
