<?php

namespace EventPortal\Tests\Feature\Admin\Permission;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Permission\Models\Permission;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class PermissionMiddlewareTest extends TestCase
{
    use DatabaseMigrations;

    /** @test **/
    public function event_show()
    {
        $user = factory(User::class)->create();
        $event = factory(Event::class)->create();
        $permission = factory(Permission::class)->create([
            'name' => 'event.show',
        ]);

        $this->actingAs($user)
            ->get(route('admin.event.show', $event))
            ->assertUnauthorized();

        $user->givePermissionTo($permission->id);

        $this->actingAs($user)
            ->get(route('admin.event.show', $event))
            ->assertOk();
    }

    /** @test **/
    public function event_store()
    {
        $user = factory(User::class)->create();
        $event = factory(Event::class)->create();
        $permission = factory(Permission::class)->create([
            'name' => 'event.store',
        ]);

        $this->actingAs($user)
            ->get(route('admin.event.create', $event))
            ->assertUnauthorized();

        $this->actingAs($user)
            ->post(route('admin.event.store', $event))
            ->assertUnauthorized();

        $user->givePermissionTo($permission->id);

        $this->actingAs($user)
            ->get(route('admin.event.create', $event))
            ->assertOk();

        // Validation varies per client, so just assert the user is authorised to post to this endpoint
        $response = $this->actingAs($user)
            ->post(route('admin.event.store', $event));

        $this->assertNotEquals(401, $response->getStatusCode());
    }

    /** @test **/
    public function event_update()
    {
        $user = factory(User::class)->create();
        $event = factory(Event::class)->create();
        $permission = factory(Permission::class)->create([
            'name' => 'event.update',
        ]);

        $this->actingAs($user)
            ->get(route('admin.event.edit', $event))
            ->assertUnauthorized();

        $this->actingAs($user)
            ->post(route('admin.event.update', $event))
            ->assertUnauthorized();

        $user->givePermissionTo($permission->id);

        $this->actingAs($user)
            ->get(route('admin.event.edit', $event))
            ->assertOk();

        // Validation varies per client, so just assert the user is authorised to post to this endpoint
        $response = $this->actingAs($user)
            ->post(route('admin.event.update', $event));

        $this->assertNotEquals(401, $response->getStatusCode());
    }

    /** @test **/
    public function event_destroy()
    {
        $user = factory(User::class)->create();
        $event = factory(Event::class)->create();
        $permission = factory(Permission::class)->create([
            'name' => 'event.destroy',
        ]);

        $this->actingAs($user)
            ->post(route('admin.event.delete', $event))
            ->assertUnauthorized();

        $user->givePermissionTo($permission->id);

        $this->actingAs($user)
            ->followingRedirects()
            ->post(route('admin.event.delete', $event))
            ->assertOk();
    }
}
