<?php

namespace EventPortal\Tests\Unit;

use EventPortal\Domain\Permission\Models\Permission;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class HelpersTest extends TestCase
{
    use DatabaseMigrations;

    /** @test */
    public function non_logged_in_user_does_not_have_permission()
    {
        $user = factory(User::class)->create();
        factory(Permission::class)->create([
            'name' => 'can do something',
            'guard_name' => 'web',
        ]);
        $user->givePermissionTo('can do something');

        $this->assertFalse(has_permission('can do something'));
    }

    /** @test */
    public function user_has_permission()
    {
        $user = factory(User::class)->create();
        factory(Permission::class)->create([
            'name' => 'can do something',
            'guard_name' => 'web',
        ]);
        $user->givePermissionTo('can do something');

        $this->actingAs($user);

        $this->assertTrue(has_permission('can do something'));
    }

    /** @test */
    public function user_does_not_have_permission()
    {
        $user = factory(User::class)->create();
        factory(Permission::class)->create([
            'name' => 'can do something',
            'guard_name' => 'web',
        ]);

        $this->actingAs($user);
        $this->assertFalse(has_permission('can do something'));
    }
}
